library(tidyr)
library(ggplot2)
library(ggpubr)
library(ggsignif)

mydata <- read.table("KaKs_sit_pha_pma_pmb.filterNA.pha_pma_pmb.header",header=T)
compaired <- list(c("Pha","PmiA"),c("Pha","PmiB"),c("PmiA","PmiB"))
p <- ggplot(mydata,aes(Group,KaKs,fill=Group))+
  geom_boxplot(width=0.5,outlier.shape=NA)+
  scale_fill_manual(values =c('#E64B35B2','#669999','#CC9966'))+
  scale_y_continuous(breaks = seq(0,1, by=0.2))+
  theme_set(theme_bw())+
  theme(plot.title=element_text(size=15),
        axis.text.x=element_text(size=15,angle=0),
        axis.text.y=element_text(size=15),
        axis.title.x=element_text(size = 15),
        axis.title.y=element_text(size = 15),
        axis.line=element_line(colour="black"),
        legend.position="none",
        panel.border=element_blank(),
        panel.grid.major=element_blank(),
        panel.grid.minor=element_blank()
        )+
  labs(x='Ka/Ks based on s.italica', y= 'Ka/Ks')+
  geom_signif(comparisons = compaired,
       step_increase = 0.03,
       map_signif_level = F,
       test = "wilcox.test",
       y_position = 0.75,
       tip_length = c(c(0.01, 0.01),c(0.01, 0.01),c(0.01, 0.01))
#       tip_length = c(0.01, 0.01,0.01, 0.01,0.01, 0.01)
       )+
  coord_cartesian(ylim=c(0, 1.3))
ggsave(p, filename="kaks-sit_pha_pma_pmb.pdf", width=3, height=3)

